@@ -1,4 +1,4 @@
-from PySide2.QtGui import QColor
+from PySide6.QtGui import QColor
 
 
 COLOR_SCHEMES = {
@@ -59,7 +59,7 @@ COLOR_SCHEMES = {
         'palette_disabled_text': QColor(0xbe, 0xbe, 0xbe, 0xff),
         'palette_disabled_buttontext': QColor(0xbe, 0xbe, 0xbe, 0xff),
         'palette_disabled_windowtext': QColor(0xbe, 0xbe, 0xbe, 0xff),
-        'palette_light': QColor(0xff, 0xff, 0xff, 0xff),
+        'palette_light': QColor(0xdf, 0xdf, 0xdf, 0xdf),
         'palette_midlight': QColor(0xca, 0xca, 0xca, 0xff),
         'palette_dark': QColor(0x9f, 0x9f, 0x9f, 0xff),
         'palette_mid': QColor(0xb8, 0xb8, 0xb8, 0xff),
@@ -74,6 +74,7 @@ COLOR_SCHEMES = {
         'pseudocode_function_color': QColor(0x00, 0x00, 0xff, 0xff),
         'pseudocode_quotation_color': QColor(0x00, 0x80, 0x00, 0xff),
         'pseudocode_keyword_color': QColor(0x00, 0x00, 0x80, 0xff),
+        'pseudocode_highlight_color': QColor(0xff, 0xff, 0x00, 0xff),
         'proximity_node_background_color': QColor(0xfa, 0xfa, 0xfa),
         'proximity_node_selected_background_color': QColor(0xcc, 0xcc, 0xcc),
         'proximity_node_border_color': QColor(0xf0, 0xf0, 0xf0),
@@ -132,23 +133,23 @@ COLOR_SCHEMES = {
         'palette_window': QColor(0x35, 0x35, 0x35),
         'palette_windowtext': QColor(0xff, 0xff, 0xff),
         'palette_base': QColor(0x28, 0x28, 0x28),
-        'palette_alternatebase': QColor(0x35, 0x35, 0x35),
+        'palette_alternatebase': QColor(0x1d, 0x1d, 0x1d),
         'palette_tooltipbase': QColor(0x35, 0x35, 0x35),
         'palette_tooltiptext': QColor(0xff, 0xff, 0xff),
-        'palette_text': QColor(0xff, 0xff, 0xff),
+        'palette_text': QColor(0xe0, 0xe0, 0xe0),
         'palette_button': QColor(0x35, 0x35, 0x35),
-        'palette_buttontext': QColor(0xff, 0xff, 0xff),
+        'palette_buttontext': QColor(0xe0, 0xe0, 0xe0),
         'palette_brighttext': QColor(0xff, 0x00, 0x00),
-        'palette_highlight': QColor(0x28, 0x28, 0x28).lighter(),
+        'palette_highlight': QColor(0x46, 0x85, 0xe5),
         'palette_highlightedtext': QColor(0xff, 0xff, 0xff),
         'palette_disabled_text': QColor(0x80, 0x80, 0x80),
         'palette_disabled_buttontext': QColor(0x80, 0x80, 0x80),
         'palette_disabled_windowtext': QColor(0x80, 0x80, 0x80),
-        'palette_light': QColor(0x00, 0x00, 0x00),
-        'palette_midlight': QColor(0x00, 0x00, 0x00),
-        'palette_dark': QColor(0x00, 0x00, 0x00),
-        'palette_mid': QColor(0x46, 0x46, 0x46),
-        'palette_shadow': QColor(0x00, 0x00, 0x00),
+        'palette_light': QColor(0x46, 0x46, 0x46),
+        'palette_midlight': QColor(0x40, 0x40, 0x40),
+        'palette_dark': QColor(0x20, 0x20, 0x20),
+        'palette_mid': QColor(0x28, 0x28, 0x28),
+        'palette_shadow': QColor(0x16, 0x16, 0x16),
         'palette_link': QColor(0x2d, 0xc5, 0x2d).lighter(),
         'palette_linkvisited': QColor(0x2d, 0xc5, 0x2d).darker(),
         'feature_map_color_regular_function': QColor(0x00, 0xa0, 0xe8),
@@ -159,6 +160,7 @@ COLOR_SCHEMES = {
         'pseudocode_function_color': QColor(0x60, 0x80, 0xff, 0xff),
         'pseudocode_quotation_color': QColor(0x00, 0x80, 0x00, 0xff),
         'pseudocode_keyword_color': QColor(0x00, 0xff, 0xff, 0xff),
+        'pseudocode_highlight_color': QColor(0x59, 0x44, 0x05, 0xff),
         'proximity_node_background_color': QColor(0x3c, 0x3c, 0x3c),
         'proximity_node_selected_background_color': QColor(0x4c, 0x50, 0x58),
         'proximity_node_border_color': QColor(0x50, 0x50, 0x50),
