@@ -1,13 +1,13 @@
 import os
 import logging
 import re
-from typing import Union, Type, Any, List, Optional
+from typing import Type, Any, List, Optional, Callable
 
 import tomlkit
 import tomlkit.exceptions
 import tomlkit.items
-from PySide2.QtGui import QFont, QFontMetricsF, QColor
-from PySide2.QtWidgets import QApplication, QMessageBox
+from PySide6.QtGui import QFont, QFontMetricsF, QColor
+from PySide6.QtWidgets import QApplication, QMessageBox
 
 from ..utils.env import app_root
 from .config_entry import ConfigurationEntry as CE
@@ -40,7 +40,7 @@ def tomltype2pytype(v, ty: Optional[Type]) -> Any:
     return str(v) if isinstance(v, tomlkit.items.String) else v.unwrap()
 
 
-def color_parser(config_option, value) -> Union[QColor, None]:
+def color_parser(config_option, value) -> Optional[QColor]:
     if not isinstance(value, str) \
        or not color_re.match(value) \
        or len(value) not in (3, 6, 8, 12):
@@ -58,7 +58,7 @@ def color_serializer(config_option, value: QColor) -> str:
     return f'{value.alpha():02x}{value.red():02x}{value.green():02x}{value.blue():02x}'
 
 
-def font_parser(config_option, value) -> Union[QFont, None]:
+def font_parser(config_option, value) -> Optional[QFont]:
     if not isinstance(value, str) or 'px ' not in value:
         _l.error('Failed to parse value %r as font for option %s', value, config_option)
         return None
@@ -163,6 +163,7 @@ ENTRIES = [
     CE('palette_alternatebase', QColor, QColor(0xf7, 0xf7, 0xf7, 0xff)),
     CE('palette_tooltipbase', QColor, QColor(0xff, 0xff, 0xdc, 0xff)),
     CE('palette_tooltiptext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
+    CE('palette_placeholdertext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
     CE('palette_text', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
     CE('palette_button', QColor, QColor(0xef, 0xef, 0xef, 0xff)),
     CE('palette_buttontext', QColor, QColor(0x00, 0x00, 0x00, 0xff)),
@@ -183,6 +184,7 @@ ENTRIES = [
     CE('pseudocode_function_color', QColor, QColor(0x00, 0x00, 0xff, 0xff)),
     CE('pseudocode_quotation_color', QColor, QColor(0x00, 0x80, 0x00, 0xff)),
     CE('pseudocode_keyword_color', QColor, QColor(0x00, 0x00, 0x80, 0xff)),
+    CE('pseudocode_highlight_color', QColor, QColor(0xff, 0xff, 0x00, 0xff)),
     CE('proximity_node_background_color', QColor, QColor(0xfa, 0xfa, 0xfa)),
     CE('proximity_node_selected_background_color', QColor, QColor(0xcc, 0xcc, 0xcc)),
     CE('proximity_node_border_color', QColor, QColor(0xf0, 0xf0, 0xf0)),
@@ -195,6 +197,8 @@ ENTRIES = [
     CE('proximity_call_node_text_color_plt', QColor, QColor(0x8b, 0x00, 0x8b)),
     CE('proximity_call_node_text_color_simproc', QColor, QColor(0x8b, 0x00, 0x8b)),
 
+    CE('log_timestamp_format', str, "%H:%M:%S"),
+
     # FLIRT signatures
     CE('flirt_signatures_root', str, "./flirt_signatures/"),
 
@@ -437,6 +441,21 @@ class ConfigurationManager: # pylint: disable=assigning-non-slot
 
         raise AttributeError(key)
 
+    def connect(self, key: str, func: Callable[[Any], None], init: bool) -> None:
+        """
+        Connect func to the QT signal emitted when the key changes
+        If init, calls func on the value associated with key after connecting
+        """
+        self._entries[key].changed.connect(func)
+        if init:
+            func(getattr(self, key))
+
+    def disconnect(self, key: str, func: Callable[[Any], None]) -> None:
+        """
+        Disconnect func from the QT signal emitted when the key changes
+        """
+        self._entries[key].changed.disconnect(func)
+
     def __dir__(self):
         return list(super().__dir__()) + list(self._entries)
 
