@@ -1,3 +1,4 @@
+# pylint:disable=global-statement
 from typing import Optional
 import logging
 import time
@@ -7,18 +8,33 @@ import ctypes
 from ...logic import GlobalInfo
 from ...logic.threads import gui_thread_schedule_async
 
-try:
-    from IPython.extensions.autoreload import ModuleReloader
-    m = ModuleReloader()
-    m.enabled = True
-    m.check_all = True
-    m.check()
-except ImportError:
-    m = None
+m = ...
+
 
 l = logging.getLogger(__name__)
 
+
+def _load_autoreload():
+    """
+    Load the autoreload extension module. Delay the import and initialization to reduce angr management's startup time.
+    """
+
+    global m
+    try:
+        from IPython.extensions.autoreload import ModuleReloader  # pylint:disable=import-outside-toplevel
+        m = ModuleReloader()
+        m.enabled = True
+        m.check_all = True
+        m.check()
+    except ImportError:
+        m = None
+
+
 class Job:
+    """
+    The base class of all Jobs in angr management.
+    """
+
     def __init__(self, name, on_finish=None, blocking=False):
         self.name = name
         self.progress_percentage = 0.
@@ -30,12 +46,15 @@ class Job:
         # callbacks
         self._on_finish = on_finish
 
-        if m is not None and GlobalInfo.autoreload:
-            prestate = dict(m.modules_mtimes)
-            m.check()
-            poststate = dict(m.modules_mtimes)
-            if prestate != poststate:
-                l.warning("Autoreload found changed modules")
+        if GlobalInfo.autoreload:
+            if m is ...:
+                _load_autoreload()
+            if m is not None:
+                prestate = dict(m.modules_mtimes)
+                m.check()
+                poststate = dict(m.modules_mtimes)
+                if prestate != poststate:
+                    l.warning("Autoreload found changed modules")
 
     @property
     def time_elapsed(self) -> str:
@@ -58,8 +77,8 @@ class Job:
     def keyboard_interrupt(self):
         """Called from the GUI thread when the user presses Ctrl+C or presses a cancel button"""
         # lol. lmao even.
-        if GlobalInfo.main_window.workspace.instance.current_job == self:
-            tid = GlobalInfo.main_window.workspace.instance.worker_thread.ident
+        if GlobalInfo.main_window.workspace.main_instance.current_job == self:
+            tid = GlobalInfo.main_window.workspace.main_instance.worker_thread.ident
             res = ctypes.pythonapi.PyThreadState_SetAsyncExc(ctypes.c_long(tid), ctypes.py_object(KeyboardInterrupt))
             if res != 1:
                 ctypes.pythonapi.PyThreadState_SetAsyncExc(ctypes.c_long(tid), 0)
