@@ -1,8 +1,8 @@
 from typing import List, Tuple, Optional
 
-import PySide2.QtCore
-from PySide2.QtCore import QSize, Qt
-from PySide2.QtWidgets import QTreeWidget, QTreeWidgetItem, QHBoxLayout, QVBoxLayout
+import PySide6.QtCore
+from PySide6.QtCore import QSize, Qt
+from PySide6.QtWidgets import QTreeWidget, QTreeWidgetItem, QHBoxLayout, QVBoxLayout
 
 from angr.project import Project
 from angr.knowledge_plugins.functions import Function
@@ -68,7 +68,7 @@ class ComponentsView(BaseView):
 
         self.setLayout(layout)
 
-    def minimumSizeHint(self) -> PySide2.QtCore.QSize:
+    def minimumSizeHint(self) -> PySide6.QtCore.QSize:
         return QSize(100, 100)
 
     def load(self, tree: ComponentTree):
@@ -76,10 +76,10 @@ class ComponentsView(BaseView):
         Display a component tree.
         """
 
-        if self.workspace.instance.project.am_none:
+        if self.workspace.main_instance.project.am_none:
             return
-        proj = self.workspace.instance.project
-        funcs = self.workspace.instance.kb.functions
+        proj = self.workspace.main_instance.project
+        funcs = self.workspace.main_instance.kb.functions
 
         self._tree.clear()
 
@@ -99,7 +99,7 @@ class ComponentsView(BaseView):
                     func = funcs.get_by_addr(proj.loader.main_object.mapped_base + comp_func.virtual_addr)
                 except KeyError:
                     func = None
-                func_node = QFunctionItem(self.workspace.instance.project, item, comp_func, function=func)
+                func_node = QFunctionItem(self.workspace.main_instance.project, item, comp_func, function=func)
                 item.function_nodes.append(func_node)
             # insert all components into the queue
             for comp in node.components:
