@@ -1,10 +1,10 @@
 import logging
 
-from PySide2.QtWidgets import QWidget, QVBoxLayout, QGraphicsScene, QGraphicsView, QGraphicsItemGroup
-from PySide2.QtWidgets import QTabWidget, QPushButton, QAbstractItemView
-from PySide2.QtWidgets import  QMessageBox, QTableWidget, QTableWidgetItem
-from PySide2.QtGui import QPen, QBrush, QLinearGradient, QColor, QPainter, QImage, QFont
-from PySide2.QtCore import Qt, QPoint, QEvent
+from PySide6.QtWidgets import QWidget, QVBoxLayout, QGraphicsScene, QGraphicsView, QGraphicsItemGroup
+from PySide6.QtWidgets import QTabWidget, QPushButton, QAbstractItemView
+from PySide6.QtWidgets import  QMessageBox, QTableWidget, QTableWidgetItem
+from PySide6.QtGui import QPen, QBrush, QLinearGradient, QColor, QPainter, QImage, QFont
+from PySide6.QtCore import Qt, QPoint, QEvent
 
 
 l = logging.getLogger(name=__name__)
@@ -71,11 +71,11 @@ class QTraceViewer(QWidget):
 
     @property
     def trace(self):
-        return self.workspace.instance.trace
+        return self.workspace.main_instance.trace
 
     @property
     def multi_trace(self):
-        return self.workspace.instance.multi_trace
+        return self.workspace.main_instance.multi_trace
 
     @property
     def selected_ins(self):
@@ -113,7 +113,7 @@ class QTraceViewer(QWidget):
         self.multiTraceList = QTableWidget(0,2) # row, col
         self.multiTraceList.setSelectionMode(QAbstractItemView.MultiSelection)
         self.multiTraceList.setSelectionBehavior(QAbstractItemView.SelectRows)
-        self.multiTraceList.setHorizontalScrollMode(self.multiTraceList.ScrollPerPixel)
+        self.multiTraceList.setHorizontalScrollMode(QAbstractItemView.ScrollPerPixel)
         self.multiTraceList.setHorizontalHeaderItem(0, QTableWidgetItem("Trace ID"))
         self.multiTraceList.setHorizontalHeaderItem(1, QTableWidgetItem("Input ID"))
         self.selectMultiTrace = QPushButton("Refresh Heatmap")
@@ -368,7 +368,7 @@ class QTraceViewer(QWidget):
             self._jump_bbl(func, bbl_addr)
 
     def _jump_bbl(self, func, bbl_addr):
-        all_insn_addrs = self.workspace.instance.project.factory.block(bbl_addr).instruction_addrs
+        all_insn_addrs = self.workspace.main_instance.project.factory.block(bbl_addr).instruction_addrs
         # TODO: replace this with am_events perhaps?
         if func is None:
             return
