@@ -1,16 +1,16 @@
-from PySide2.QtWidgets import QDialog, QVBoxLayout
-from PySide2.QtCore import QSize, Qt
+from PySide6.QtWidgets import QDialog, QVBoxLayout
+from PySide6.QtCore import QSize, Qt
 
 from ..widgets.qxref_viewer import QXRefViewer
 
 
-class XRef(QDialog):
+class XRefDialog(QDialog):
     """
     Dialog displaying cross-references.
     """
 
     def __init__(self, addr=None, variable_manager=None, variable=None, xrefs_manager=None, dst_addr=None,
-                 instance=None, parent=None):
+                 instance=None, disassembly_view=None, parent=None):
         super().__init__(parent)
 
         self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
@@ -21,7 +21,7 @@ class XRef(QDialog):
         self._addr = addr  # current address
         self._dst_addr = dst_addr
         self._instance = instance
-        self._disassembly_view = parent
+        self._disassembly_view = disassembly_view
 
         if variable is not None:
             self.setWindowTitle(f'XRefs to variable {variable.name}({variable.ident})')
@@ -49,7 +49,7 @@ class XRef(QDialog):
         xref_viewer = QXRefViewer(
             addr=self._addr, variable_manager=self._variable_manager, variable=self._variable,
             xrefs_manager=self._xrefs_manager, dst_addr=self._dst_addr,
-            instance=self._instance, disassembly_view=self._disassembly_view, parent=self,
+            instance=self._instance, xref_dialog=self, parent=self,
         )
 
         layout = QVBoxLayout()
@@ -58,5 +58,9 @@ class XRef(QDialog):
         self.setLayout(layout)
 
     def jump_to(self, addr):
-        self._disassembly_view.jump_to(addr, src_ins_addr=self._addr)
+        disasm_view = self._disassembly_view
+        if disasm_view is None:
+            disasm_view = self._instance.workspace.view_manager.first_view_in_category("disassembly")
+        disasm_view.jump_to(addr, src_ins_addr=self._addr)
+        disasm_view.focus()
         self.close()
