@@ -7,10 +7,11 @@ import time
 from functools import partial
 from typing import Optional, TYPE_CHECKING
 
-from PySide2.QtWidgets import QMainWindow, QTabWidget, QFileDialog, QProgressBar, QProgressDialog
-from PySide2.QtWidgets import QMessageBox, QShortcut, QTabBar
-from PySide2.QtGui import QIcon, QDesktopServices, QKeySequence
-from PySide2.QtCore import Qt, QSize, QEvent, QUrl
+from PySide6.QtWidgets import QMainWindow, QFileDialog, QProgressBar, QProgressDialog
+from PySide6.QtWidgets import QMessageBox
+from PySide6.QtGui import QIcon, QDesktopServices, QKeySequence, QShortcut
+from PySide6.QtCore import Qt, QSize, QEvent, QUrl
+import PySide6QtAds as QtAds
 
 import angr
 import angr.flirt
@@ -53,7 +54,8 @@ from .toolbars import FileToolbar, DebugToolbar
 from .toolbar_manager import ToolbarManager
 
 if TYPE_CHECKING:
-    from PySide2.QtWidgets import QApplication
+    from PySide6.QtWidgets import QApplication
+
 
 _l = logging.getLogger(name=__name__)
 
@@ -65,9 +67,11 @@ class MainWindow(QMainWindow):
 
     def __init__(self, app: Optional['QApplication'] = None, parent=None, show=True, use_daemon=False):
         super().__init__(parent)
+        self.initialized = False
 
         icon_location = os.path.join(IMG_LOCATION, 'angr.png')
         self.setWindowIcon(QIcon(icon_location))
+        self.setWindowTitle("angr management")
 
         GlobalInfo.main_window = self
         self.shown_at_start = show
@@ -162,12 +166,12 @@ class MainWindow(QMainWindow):
         dlg.exec_()
 
     def open_newstate_dialog(self):
-        if self.workspace.instance.project.am_none:
+        if self.workspace.main_instance.project.am_none:
             QMessageBox.critical(self,
                                  "Cannot create new states",
                                  "Please open a binary to analyze first.")
             return
-        new_state_dialog = NewState(self.workspace.instance, parent=self, create_simgr=True)
+        new_state_dialog = NewState(self.workspace.main_instance, parent=self, create_simgr=True)
         new_state_dialog.exec_()
 
     def open_doc_link(self):
@@ -198,7 +202,7 @@ class MainWindow(QMainWindow):
         def on_cancel():
             if self.workspace is None:
                 return
-            for job in self.workspace.instance.jobs:
+            for job in self.workspace.main_instance.jobs:
                 if job.blocking:
                     job.keyboard_interrupt()
                     break
@@ -244,33 +248,31 @@ class MainWindow(QMainWindow):
 
         :return:    None
         """
-        self.central_widget = QMainWindow()
-        self.setCentralWidget(self.central_widget)
+        QtAds.CDockManager.setConfigFlags(
+            (QtAds.CDockManager.DefaultBaseConfig | QtAds.CDockManager.OpaqueSplitterResize)
+            & ~QtAds.CDockManager.DockAreaHasUndockButton)
+        self.dock_manager = QtAds.CDockManager(self)
+        self.dock_manager.setStyleSheet("")  # Clear stylesheet overrides
+        self.central_widget = self.dock_manager
         wk = Workspace(self, Instance())
         self.workspace = wk
-        self.workspace.view_manager.tabify_center_views()
-        self.central_widget.setTabPosition(Qt.RightDockWidgetArea, QTabWidget.North)
-        self.central_widget.setDockNestingEnabled(True)
 
         def set_caption(**kwargs):  # pylint: disable=unused-argument
-            if self.workspace.instance.project.am_none:
+            if self.workspace.main_instance.project.am_none:
                 self.caption = ''
-            elif self.workspace.instance.project.filename is None:
+            elif self.workspace.main_instance.project.filename is None:
                 self.caption = "Loaded from stream"
             else:
-                self.caption = os.path.basename(self.workspace.instance.project.filename)
+                self.caption = os.path.basename(self.workspace.main_instance.project.filename)
 
-        self.workspace.instance.project.am_subscribe(set_caption)
-
-        self.tab = self.central_widget.findChild(QTabBar)
-        self.tab.tabBarClicked.connect(self.on_center_tab_clicked)
+        self.workspace.main_instance.project.am_subscribe(set_caption)
 
     #
     # Shortcuts
     #
 
     def interrupt_current_job(self):
-        self.workspace.instance.interrupt_current_job()
+        self.workspace.main_instance.interrupt_current_job()
 
     def _init_shortcuts(self):
         """
@@ -281,7 +283,7 @@ class MainWindow(QMainWindow):
 
         center_dockable_views = self.workspace.view_manager.get_center_views()
         for i in range(1, len(center_dockable_views) + 1):
-            QShortcut(QKeySequence('Ctrl+' + str(i)), self, center_dockable_views[i - 1].raise_)
+            QShortcut(QKeySequence('Alt+' + str(i)), self, center_dockable_views[i - 1].raise_)
 
         QShortcut(QKeySequence("Ctrl+I"), self, self.interrupt_current_job)
 
@@ -405,7 +407,9 @@ class MainWindow(QMainWindow):
     def closeEvent(self, event):
 
         # Ask if the user wants to save things
-        if self.workspace.instance is not None and not self.workspace.instance.project.am_none:
+        if self.workspace.main_instance is not None \
+                and not self.workspace.main_instance.project.am_none \
+                and self.shown_at_start:
             msgbox = QMessageBox()
             msgbox.setWindowTitle("Save database")
             msgbox.setText("angr management is about to exit. Do you want to save the database?")
@@ -425,7 +429,7 @@ class MainWindow(QMainWindow):
                     event.ignore()
                     return
 
-        for plugin in list(self.workspace.plugins.active_plugins):
+        for plugin in list(self.workspace.plugins.active_plugins.values()):
             self.workspace.plugins.deactivate_plugin(plugin)
         event.accept()
 
@@ -451,9 +455,6 @@ class MainWindow(QMainWindow):
         self.workspace.current_screen.am_obj = screen
         self.workspace.current_screen.am_event()
 
-    def on_center_tab_clicked(self, index):
-        self.workspace.view_manager.handle_center_tab_click(index)
-
     #
     # Actions
     #
@@ -494,8 +495,8 @@ class MainWindow(QMainWindow):
         if img_name is None:
             return
         target = archr.targets.DockerImageTarget(img_name, target_path=None)
-        self.workspace.instance.add_job(LoadTargetJob(target))
-        self.workspace.instance.img_name = img_name
+        self.workspace.main_instance.add_job(LoadTargetJob(target))
+        self.workspace.main_instance.img_name = img_name
 
     def load_trace_file(self, file_path):
         if isurl(file_path):
@@ -536,13 +537,13 @@ class MainWindow(QMainWindow):
                     self.workspace.load_trace_from_path(file_path)
                     return
 
-                self.workspace.instance.binary_path = file_path
-                self.workspace.instance.original_binary_path = file_path
+                self.workspace.main_instance.binary_path = file_path
+                self.workspace.main_instance.original_binary_path = file_path
                 if file_path.endswith(".adb"):
                     self._load_database(file_path)
                 else:
                     self._recent_file(file_path)
-                    self.workspace.instance.add_job(LoadBinaryJob(file_path))
+                    self.workspace.main_instance.add_job(LoadBinaryJob(file_path))
             else:
                 QMessageBox.critical(self,
                                      "File not found",
@@ -571,8 +572,8 @@ class MainWindow(QMainWindow):
 
                 if target_path:
                     # open the file - now it's a local file
-                    self.workspace.instance.binary_path = target_path
-                    self.workspace.instance.original_binary_path = file_path
+                    self.workspace.main_instance.binary_path = target_path
+                    self.workspace.main_instance.original_binary_path = file_path
                     self.load_file(target_path)
 
     def load_database(self):
@@ -588,22 +589,22 @@ class MainWindow(QMainWindow):
         self._load_database(file_path)
 
     def save_database(self):
-        if self.workspace.instance is None or self.workspace.instance.project.am_none:
+        if self.workspace.main_instance is None or self.workspace.main_instance.project.am_none:
             return True
 
-        if self.workspace.instance.database_path is None:
+        if self.workspace.main_instance.database_path is None:
             return self.save_database_as()
         else:
-            return self._save_database(self.workspace.instance.database_path)
+            return self._save_database(self.workspace.main_instance.database_path)
 
     def save_database_as(self):
 
-        if self.workspace.instance is None or self.workspace.instance.project.am_none:
+        if self.workspace.main_instance is None or self.workspace.main_instance.project.am_none:
             return False
 
-        default_database_path = self.workspace.instance.database_path
+        default_database_path = self.workspace.main_instance.database_path
         if default_database_path is None:
-            default_database_path = os.path.normpath(self.workspace.instance.project.filename) + ".adb"
+            default_database_path = os.path.normpath(self.workspace.main_instance.project.filename) + ".adb"
 
         # Open File window
         file_path, _ = QFileDialog.getSaveFileName(
@@ -639,14 +640,14 @@ class MainWindow(QMainWindow):
         self.workspace._get_or_create_disassembly_view().run_induction_variable_analysis()
 
     def run_dependency_analysis(self, func_addr: Optional[int] = None, func_arg_idx: Optional[int] = None):
-        if self.workspace is None or self.workspace.instance is None:
+        if self.workspace is None or self.workspace.main_instance is None:
             return
         dep_analysis_job = DependencyAnalysisJob(func_addr=func_addr, func_arg_idx=func_arg_idx)
-        self.workspace.instance.add_job(dep_analysis_job)
+        self.workspace.main_instance.add_job(dep_analysis_job)
 
     def run_analysis(self):
         if self.workspace:
-            self.workspace.run_analysis()
+            self.workspace.main_instance.run_analysis()
 
     def decompile_current_function(self):
         if self.workspace is not None:
@@ -657,7 +658,7 @@ class MainWindow(QMainWindow):
             self.workspace.view_proximity_for_current_function()
 
     def interact(self):
-        self.workspace.interact_program(self.workspace.instance.img_name)
+        self.workspace.interact_program(self.workspace.main_instance.img_name)
 
     #
     # Other public methods
@@ -703,7 +704,7 @@ class MainWindow(QMainWindow):
 
         job = LoadAngrDBJob(file_path, ["global", "pseudocode_variable_kb"], other_kbs=other_kbs, extra_info=extra_info)
         job._on_finish = partial(self._on_load_database_finished, job)
-        self.workspace.instance.add_job(job)
+        self.workspace.main_instance.add_job(job)
 
     def _on_load_database_finished(self, job: LoadAngrDBJob):
         proj = job.project
@@ -716,25 +717,25 @@ class MainWindow(QMainWindow):
         cfg = proj.kb.cfgs['CFGFast']
         cfb = proj.analyses.CFB()  # it will load functions from kb
 
-        self.workspace.instance.database_path = job.file_path
+        self.workspace.main_instance.database_path = job.file_path
 
-        self.workspace.instance._reset_containers()
-        self.workspace.instance.project = proj
-        self.workspace.instance.cfg = cfg
-        self.workspace.instance.cfb = cfb
+        self.workspace.main_instance._reset_containers()
+        self.workspace.main_instance.project = proj
+        self.workspace.main_instance.cfg = cfg
+        self.workspace.main_instance.cfb = cfb
         if "pseudocode_variable_kb" in job.other_kbs:
-            self.workspace.instance.pseudocode_variable_kb = job.other_kbs["pseudocode_variable_kb"]
+            self.workspace.main_instance.pseudocode_variable_kb = job.other_kbs["pseudocode_variable_kb"]
         else:
-            self.workspace.instance.initialize_pseudocode_variable_kb()
-        self.workspace.instance.project.am_event(initialized=True)
+            self.workspace.main_instance.initialize_pseudocode_variable_kb()
+        self.workspace.main_instance.project.am_event(initialized=True)
 
         # trigger callbacks
         self.workspace.reload()
-        self.workspace.on_cfg_generated()
+        self.workspace.main_instance.on_cfg_generated()
         self.workspace.plugins.angrdb_load_entries(job.extra_info)
 
     def _save_database(self, file_path):
-        if self.workspace.instance is None or self.workspace.instance.project.am_none:
+        if self.workspace.main_instance is None or self.workspace.main_instance.project.am_none:
             return False
 
         if AngrDB is None:
@@ -744,14 +745,14 @@ class MainWindow(QMainWindow):
 
         self.workspace.plugins.handle_project_save(file_path)
 
-        angrdb = AngrDB(project=self.workspace.instance.project)
+        angrdb = AngrDB(project=self.workspace.main_instance.project)
         extra_info = self.workspace.plugins.angrdb_store_entries()
         angrdb.dump(file_path, kbs=[
-                self.workspace.instance.kb,
-                self.workspace.instance.pseudocode_variable_kb,
+                self.workspace.main_instance.kb,
+                self.workspace.main_instance.pseudocode_variable_kb,
                 ],
             extra_info=extra_info,
             )
 
-        self.workspace.instance.database_path = file_path
+        self.workspace.main_instance.database_path = file_path
         return True
