@@ -1,6 +1,6 @@
 
-from PySide2.QtGui import QKeySequence
-from PySide2.QtCore import Qt
+from PySide6.QtGui import QKeySequence
+from PySide6.QtCore import Qt
 
 from .menu import Menu, MenuEntry, MenuSeparator
 
@@ -17,7 +17,7 @@ class AnalyzeMenu(Menu):
                 shortcut=QKeySequence(Qt.Key_F5)),
             MenuEntry('View in Proximity &Browser',
                       main_window.view_proximity_for_current_function,
-                      shortcut=QKeySequence(Qt.CTRL + Qt.Key_B)),
+                      shortcut=QKeySequence(Qt.CTRL | Qt.Key_B)),
             MenuEntry('&Interact',
                 main_window.interact,
                 shortcut=QKeySequence(Qt.Key_F6)),
