@@ -1,6 +1,6 @@
 
-from PySide2.QtGui import QKeySequence
-from PySide2.QtCore import Qt
+from PySide6.QtGui import QKeySequence
+from PySide6.QtCore import Qt
 
 from .menu import Menu, MenuEntry, MenuSeparator
 
@@ -10,7 +10,7 @@ class HelpMenu(Menu):
         super().__init__("&Help", parent=main_window)
 
         self.entries.extend([
-            MenuEntry('&Documentation', main_window.open_doc_link,  shortcut=QKeySequence(Qt.ALT + Qt.Key_H)),
+            MenuEntry('&Documentation', main_window.open_doc_link,  shortcut=QKeySequence(Qt.ALT | Qt.Key_H)),
             MenuSeparator(),
             MenuEntry('About angr...', main_window.open_about_dialog)
         ])
