@@ -1,9 +1,9 @@
 from typing import Set, Union, Optional
 import logging
 
-from PySide2.QtWidgets import QHBoxLayout, QTextEdit, QMainWindow, QDockWidget, QVBoxLayout, QWidget, QFrame, QComboBox
-from PySide2.QtGui import QTextCursor
-from PySide2.QtCore import Qt
+from PySide6.QtWidgets import QHBoxLayout, QTextEdit, QMainWindow, QDockWidget, QVBoxLayout, QWidget, QFrame, QComboBox
+from PySide6.QtGui import QTextCursor
+from PySide6.QtCore import Qt
 
 from angr.analyses.decompiler.structured_codegen.c import CFunctionCall, CConstant, CStructuredCodeGenerator
 from angr.analyses.decompiler.structured_codegen import DummyStructuredCodeGenerator
@@ -13,9 +13,10 @@ from ..widgets.qccode_edit import QCCodeEdit
 from ..widgets.qdecomp_options import QDecompilationOptions
 from ..documents import QCodeDocument
 from .view import BaseView
+from ...config import Conf
 from ...data.object_container import ObjectContainer
 from ...logic.disassembly import JumpHistory
-from ...data.jobs import DecompileFunctionJob
+from ...data.jobs import DecompileFunctionJob, VariableRecoveryJob
 from ..toolbars import NavToolbar
 
 
@@ -30,8 +31,8 @@ class CodeView(BaseView):
 
     FUNCTION_SPECIFIC_VIEW = True
 
-    def __init__(self, workspace, default_docking_position, *args, **kwargs):
-        super().__init__('pseudocode', workspace, default_docking_position, *args, **kwargs)
+    def __init__(self, instance, default_docking_position, *args, **kwargs):
+        super().__init__('pseudocode', instance, default_docking_position, *args, **kwargs)
 
         self.base_caption = 'Pseudocode'
 
@@ -95,7 +96,7 @@ class CodeView(BaseView):
     #
 
     def reload(self):
-        if self.workspace.instance.project.am_none:
+        if self.instance.project.am_none:
             return
         self._options.reload(force=True)
         self.vars_must_struct = set()
@@ -111,18 +112,18 @@ class CodeView(BaseView):
             self._function.ran_cca = False
 
         if reset_cache:
-            self.workspace.instance.kb.structured_code.discard((self._function.addr, flavor))
-            variables = self.workspace.instance.pseudocode_variable_kb.variables
+            self.instance.kb.structured_code.discard((self._function.addr, flavor))
+            variables = self.instance.pseudocode_variable_kb.variables
             if variables.has_function_manager(self._function.addr):
                 del variables[self._function.addr]
 
         def decomp_ready():
             # this code is _partially_ duplicated from _on_new_function. be careful!
-            available = self.workspace.instance.kb.structured_code.available_flavors(self._function.addr)
+            available = self.instance.kb.structured_code.available_flavors(self._function.addr)
             self._update_available_views(available)
             if available:
                 chosen_flavor = flavor if flavor in available else available[0]
-                self.codegen.am_obj = self.workspace.instance.kb.structured_code[(self._function.addr,
+                self.codegen.am_obj = self.instance.kb.structured_code[(self._function.addr,
                                                                                   chosen_flavor)].codegen
                 self.codegen.am_event(already_regenerated=True)
                 self._focus_core(focus, focus_addr)
@@ -131,19 +132,31 @@ class CodeView(BaseView):
                 else:
                     self.jump_history.record_address(self._function.am_obj.addr)
 
-        job = DecompileFunctionJob(
-            self._function.am_obj,
-            cfg=self.workspace.instance.cfg,
-            options=self._options.option_and_values,
-            optimization_passes=self._options.selected_passes,
-            peephole_optimizations=self._options.selected_peephole_opts,
-            vars_must_struct=self.vars_must_struct,
-            on_finish=decomp_ready,
-            blocking=True,
-            regen_clinic=regen_clinic,
-        )
+        def decomp():
+            job = DecompileFunctionJob(
+                self._function.am_obj,
+                cfg=self.instance.cfg,
+                options=self._options.option_and_values,
+                optimization_passes=self._options.selected_passes,
+                peephole_optimizations=self._options.selected_peephole_opts,
+                vars_must_struct=self.vars_must_struct,
+                on_finish=decomp_ready,
+                blocking=True,
+                regen_clinic=regen_clinic,
+            )
+            self.instance.add_job(job)
 
-        self.workspace.instance.add_job(job)
+        if self._function.ran_cca is False:
+            # run calling convention analysis for this function
+            varrec_job = VariableRecoveryJob(
+                **self.instance._analysis_configuration['varec'].to_dict(),
+                workers=0,
+                on_finish=decomp,
+                func_addr=self._function.addr
+            )
+            self.instance.add_job(varrec_job)
+        else:
+            decomp()
 
     def highlight_chunks(self, chunks):
         extra_selections = [ ]
@@ -152,7 +165,7 @@ class CodeView(BaseView):
             sel.cursor = self._textedit.textCursor()
             sel.cursor.setPosition(start)
             sel.cursor.setPosition(end, QTextCursor.KeepAnchor)
-            sel.format.setBackground(Qt.yellow)
+            sel.format.setBackground(Conf.pseudocode_highlight_color)
             extra_selections.append(sel)
         self._textedit.setExtraSelections(extra_selections)
 
@@ -178,10 +191,10 @@ class CodeView(BaseView):
                 self._focus_core(True, None)
         else:
             # try to find the right function
-            block_addr, _ = self.workspace.instance.cfb.floor_item(self.addr.am_obj)
-            block = self.workspace.instance.cfg.get_any_node(block_addr)
+            block_addr, _ = self.instance.cfb.floor_item(self.addr.am_obj)
+            block = self.instance.cfg.get_any_node(block_addr)
             if block is not None:
-                func = self.workspace.instance.kb.functions[block.function_address]
+                func = self.instance.kb.functions[block.function_address]
                 if func is not self._function.am_obj:
                     self._function.am_obj = func
                     self._function.am_event(focus_addr=self.addr.am_obj, focus=focus)
@@ -230,12 +243,12 @@ class CodeView(BaseView):
             pass
         else:
             if event == "retype_variable":
-                dec = self.workspace.instance.project.analyses.Decompiler(
+                dec = self.instance.project.analyses.Decompiler(
                     self._function,
-                    variable_kb=self.workspace.instance.pseudocode_variable_kb,
+                    variable_kb=self.instance.pseudocode_variable_kb,
                     decompile=False
                 )
-                dec_cache = self.workspace.instance.kb.structured_code[(self._function.addr, 'pseudocode')]
+                dec_cache = self.instance.kb.structured_code[(self._function.addr, 'pseudocode')]
                 new_codegen = dec.reflow_variable_types(
                     dec_cache.type_constraints,
                     dec_cache.var_to_typevar or {},
@@ -289,12 +302,12 @@ class CodeView(BaseView):
         if not self.codegen.am_none and self._last_function is self._function.am_obj:
             self._focus_core(focus, focus_addr)
             return
-        available = self.workspace.instance.kb.structured_code.available_flavors(self._function.addr)
+        available = self.instance.kb.structured_code.available_flavors(self._function.addr)
         self._update_available_views(available)
         should_decompile = True
         if available:
             chosen_flavor = flavor if flavor in available else available[0]
-            cached = self.workspace.instance.kb.structured_code[(self._function.addr, chosen_flavor)].codegen
+            cached = self.instance.kb.structured_code[(self._function.addr, chosen_flavor)].codegen
             if not isinstance(cached, DummyStructuredCodeGenerator):
                 should_decompile = False
                 self.codegen.am_obj = cached
@@ -336,11 +349,11 @@ class CodeView(BaseView):
                 if selected_node.callee_func is not None:
                     self.jump_history.record_address(selected_node.tags['ins_addr'])
                     self.jump_history.jump_to(selected_node.callee_func.addr)
-                    self.workspace.decompile_function(selected_node.callee_func, view=self)
+                    self.instance.workspace.decompile_function(selected_node.callee_func, view=self)
             elif isinstance(selected_node, CConstant):
                 # jump to highlighted constants
                 if selected_node.reference_values is not None and selected_node.value is not None:
-                    self.workspace.jump_to(selected_node.value)
+                    self.instance.workspace.jump_to(selected_node.value)
 
     def _jump_to(self, addr:int):
         self.addr.am_obj = addr
@@ -367,7 +380,7 @@ class CodeView(BaseView):
         key = event.key()
         if key == Qt.Key_Tab:
             # Switch back to disassembly view
-            self.workspace.jump_to(self.addr.am_obj)
+            self.instance.workspace.jump_to(self.addr.am_obj)
             return True
         elif key == Qt.Key_Escape:
             self.jump_back()
@@ -375,10 +388,10 @@ class CodeView(BaseView):
         elif key == Qt.Key_Space:
             if not self.codegen.am_none:
                 flavor = self.codegen.flavor
-                flavors = self.workspace.instance.kb.structured_code.available_flavors(self._function.addr)
+                flavors = self.instance.kb.structured_code.available_flavors(self._function.addr)
                 idx = flavors.index(flavor)
                 newidx = (idx + 1) % len(flavors)
-                self.codegen.am_obj = self.workspace.instance.kb.structured_code[(self._function.addr,
+                self.codegen.am_obj = self.instance.kb.structured_code[(self._function.addr,
                                                                                   flavors[newidx])].codegen
                 self.codegen.am_event()
                 return True
@@ -394,7 +407,7 @@ class CodeView(BaseView):
     def _on_view_selector_changed(self, index):
         if not self._function.am_none:
             key = (self._function.addr, self._view_selector.itemText(index))
-            self.codegen.am_obj = self.workspace.instance.kb.structured_code[key].codegen
+            self.codegen.am_obj = self.instance.kb.structured_code[key].codegen
             self.codegen.am_event()
 
     #
@@ -415,7 +428,7 @@ class CodeView(BaseView):
         textedit_dock.setWidget(self._textedit)
 
         # decompilation
-        self._options = QDecompilationOptions(self, self.workspace.instance)
+        self._options = QDecompilationOptions(self, self.instance)
         options_dock = QDockWidget('Decompilation Options', self._options)
         window.addDockWidget(Qt.RightDockWidgetArea, options_dock)
         options_dock.setWidget(self._options)
@@ -430,27 +443,30 @@ class CodeView(BaseView):
             True,
             self)
         self._view_selector = QComboBox()
-        self._view_selector.addItems(["pseudocode"])
+        self._view_selector.addItems(["Pseudocode"])
         self._view_selector.activated.connect(self._on_view_selector_changed)
         status_layout = QHBoxLayout()
         status_layout.addWidget(self._nav_toolbar.qtoolbar())
         status_layout.addStretch(0)
         status_layout.addWidget(self._view_selector)
-        status_layout.setContentsMargins(0, 0, 0, 0)
+        status_layout.setContentsMargins(3, 3, 3, 3)
         status_bar.setLayout(status_layout)
 
         inner_layout = QHBoxLayout()
         inner_layout.addWidget(window)
         inner_layout.setContentsMargins(0, 0, 0, 0)
+        inner_layout.setSpacing(0)
         inner_widget = QWidget()
         inner_widget.setLayout(inner_layout)
 
         outer_layout = QVBoxLayout()
-        outer_layout.addWidget(inner_widget)
         outer_layout.addWidget(status_bar)
+        outer_layout.addWidget(inner_widget)
+        outer_layout.setContentsMargins(0, 0, 0, 0)
+        outer_layout.setSpacing(0)
 
         self.setLayout(outer_layout)
 
         self._textedit.focusWidget()
 
-        self.workspace.plugins.instrument_code_view(self)
+        self.instance.workspace.plugins.instrument_code_view(self)
