@@ -1,7 +1,7 @@
 
 import logging
-from PySide2.QtWidgets import QHBoxLayout
-from PySide2.QtCore import QSize
+from PySide6.QtWidgets import QHBoxLayout
+from PySide6.QtCore import QSize
 from traitlets.config.configurable import MultipleInstanceError
 
 from .view import BaseView
@@ -14,19 +14,23 @@ class ConsoleView(BaseView):
     Console view providing IPython interactive session.
     """
 
-    def __init__(self, workspace, default_docking_position, *args, **kwargs):
-        super().__init__('console', workspace, default_docking_position, *args, **kwargs)
+    def __init__(self, instance, default_docking_position, *args, **kwargs):
+        super().__init__('console', instance, default_docking_position, *args, **kwargs)
 
         self.base_caption = 'Console'
         self._ipython_widget = None
 
-        self._init_widgets()
-        self.reload()
+        if self.instance.workspace.main_window.initialized:
+            self.mainWindowInitializedEvent()
 
     @property
     def ipython_widget_available(self):
         return self._ipython_widget is not None
 
+    def mainWindowInitializedEvent(self):
+        self._init_widgets()
+        self.reload()
+
     def reload(self):
 
         if self._ipython_widget is None:
@@ -37,9 +41,9 @@ class ConsoleView(BaseView):
         namespace = {'angr': angr,
                      'claripy': claripy,
                      'cle': cle,
-                     'workspace': self.workspace,
-                     'instance': self.workspace.instance,
-                     'project': self.workspace.instance.project,
+                     'workspace': self.instance.workspace,
+                     'instance': self.instance,
+                     'project': self.instance.project,
                      }
         self._ipython_widget.push_namespace(namespace)
 
@@ -87,11 +91,12 @@ class ConsoleView(BaseView):
 
         hlayout = QHBoxLayout()
         hlayout.addWidget(ipython_widget)
+        hlayout.setContentsMargins(0, 0, 0, 0)
 
         self.setLayout(hlayout)
 
     def command_executed(self,msg):
         if msg["msg_type"] == "execute_reply" and msg["content"]["status"] == "ok":
-            view = self.workspace.view_manager.first_view_in_category("disassembly")
+            view = self.instance.workspace.view_manager.first_view_in_category("disassembly")
             if view is not None:
                 view.refresh()
