@@ -2,10 +2,10 @@ import functools
 import logging
 from typing import Any, Optional
 
-import PySide2
-from PySide2.QtGui import QFont, QCursor
-from PySide2.QtCore import QAbstractTableModel, Qt, QSize
-from PySide2.QtWidgets import QTableView, QAbstractItemView, QHeaderView, QVBoxLayout, QMenu, QAction
+import PySide6
+from PySide6.QtGui import QFont, QCursor, QAction
+from PySide6.QtCore import QAbstractTableModel, Qt, QSize
+from PySide6.QtWidgets import QTableView, QAbstractItemView, QHeaderView, QVBoxLayout, QMenu
 
 
 import angr
@@ -33,20 +33,20 @@ class QStackTableModel(QAbstractTableModel):
         self._log_widget = log_widget
         self.state: angr.SimState = None
 
-    def rowCount(self, parent:PySide2.QtCore.QModelIndex=...) -> int:  # pylint:disable=unused-argument
+    def rowCount(self, parent:PySide6.QtCore.QModelIndex=...) -> int:  # pylint:disable=unused-argument
         return 0 if self.state is None else 15
 
-    def columnCount(self, parent:PySide2.QtCore.QModelIndex=...) -> int:  # pylint:disable=unused-argument
+    def columnCount(self, parent:PySide6.QtCore.QModelIndex=...) -> int:  # pylint:disable=unused-argument
         return len(self.Headers)
 
-    def headerData(self, section:int, orientation:PySide2.QtCore.Qt.Orientation, role:int=...) -> Any:  # pylint:disable=unused-argument
+    def headerData(self, section:int, orientation:PySide6.QtCore.Qt.Orientation, role:int=...) -> Any:  # pylint:disable=unused-argument
         if role != Qt.DisplayRole:
             return None
         if section < len(self.Headers):
             return self.Headers[section]
         return None
 
-    def data(self, index:PySide2.QtCore.QModelIndex, role:int=...) -> Any:
+    def data(self, index:PySide6.QtCore.QModelIndex, role:int=...) -> Any:
         if not index.isValid():
             return None
         row = index.row()
@@ -87,7 +87,7 @@ class QStackTableWidget(QTableView):
         vheader.setDefaultSectionSize(20)
 
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
-        self.setHorizontalScrollMode(self.ScrollPerPixel)
+        self.setHorizontalScrollMode(QAbstractItemView.ScrollPerPixel)
 
         self.model: QStackTableModel = QStackTableModel(self)
         self.setModel(self.model)
@@ -97,7 +97,7 @@ class QStackTableWidget(QTableView):
 
         hheader.setSectionResizeMode(0, QHeaderView.ResizeToContents)
 
-        self._dbg_manager = stack_view.workspace.instance.debugger_mgr
+        self._dbg_manager = stack_view.instance.debugger_mgr
         self._dbg_watcher = DebuggerWatcher(self._on_debugger_state_updated, self._dbg_manager.debugger)
         self._on_debugger_state_updated()
 
@@ -115,7 +115,7 @@ class QStackTableWidget(QTableView):
         self.model.layoutChanged.emit()
         self.update()
 
-    def contextMenuEvent(self, arg__1:PySide2.QtGui.QContextMenuEvent):  # pylint:disable=unused-argument
+    def contextMenuEvent(self, arg__1:PySide6.QtGui.QContextMenuEvent):  # pylint:disable=unused-argument
         if not self.selectedIndexes():
             return
 
@@ -137,7 +137,7 @@ class QStackTableWidget(QTableView):
         row = selected[0].row()
         width = state.arch.bits // 8
         offset = row * width + state.solver.eval(state.regs.sp)
-        self.stack_view.workspace.instance.breakpoint_mgr.add_breakpoint(
+        self.stack_view.instance.breakpoint_mgr.add_breakpoint(
             Breakpoint(bp_type, offset, width)
         )
 
@@ -163,8 +163,8 @@ class StackView(BaseView):
     Stack table view.
     """
 
-    def __init__(self, workspace, default_docking_position, *args, **kwargs):
-        super().__init__('stack', workspace, default_docking_position, *args, **kwargs)
+    def __init__(self, instance, default_docking_position, *args, **kwargs):
+        super().__init__('stack', instance, default_docking_position, *args, **kwargs)
 
         self.base_caption = 'Stack'
         self._tbl_widget: Optional[QStackTableWidget] = None
