@@ -1,6 +1,6 @@
 import re
-from PySide2.QtWidgets import QCheckBox, QHBoxLayout, QLineEdit, QVBoxLayout, QLabel
-from PySide2.QtCore import QSize
+from PySide6.QtWidgets import QCheckBox, QHBoxLayout, QLineEdit, QVBoxLayout, QLabel
+from PySide6.QtCore import QSize
 
 from angr.knowledge_plugins import Function
 from angr.knowledge_plugins.cfg.memory_data import MemoryData
@@ -11,8 +11,8 @@ from ..widgets.qfunction_combobox import QFunctionComboBox
 
 
 class StringsView(BaseView):
-    def __init__(self, workspace, default_docking_position, *args, **kwargs):
-        super(StringsView, self).__init__('strings', workspace, default_docking_position, *args, **kwargs)
+    def __init__(self, instance, default_docking_position, *args, **kwargs):
+        super(StringsView, self).__init__('strings', instance, default_docking_position, *args, **kwargs)
 
         self.base_caption = 'Strings'
 
@@ -25,11 +25,11 @@ class StringsView(BaseView):
         self.reload()
 
     def reload(self):
-        if self.workspace.instance.kb is None:
+        if self.instance.kb is None:
             return
-        self._function_list.functions = self.workspace.instance.kb.functions
-        self._string_table.cfg = self.workspace.instance.cfg
-        self._string_table.xrefs = self.workspace.instance.project.kb.xrefs
+        self._function_list.functions = self.instance.kb.functions
+        self._string_table.cfg = self.instance.cfg
+        self._string_table.xrefs = self.instance.project.kb.xrefs
         self._string_table.function = self._selected_function
 
     def sizeHint(self):
@@ -58,14 +58,14 @@ class StringsView(BaseView):
         :return:
         """
 
-        if len(self.workspace.view_manager.views_by_category['disassembly']) == 1:
-            disasm_view = self.workspace.view_manager.first_view_in_category('disassembly')
+        if len(self.instance.workspace.view_manager.views_by_category['disassembly']) == 1:
+            disasm_view = self.instance.workspace.view_manager.first_view_in_category('disassembly')
         else:
-            disasm_view = self.workspace.view_manager.current_view_in_category('disassembly')
+            disasm_view = self.instance.workspace.view_manager.current_view_in_category('disassembly')
         if disasm_view is not None:
             disasm_view.jump_to(s.addr)
             disasm_view.select_label(s.addr)
-            self.workspace.view_manager.raise_view(disasm_view)
+            self.instance.workspace.view_manager.raise_view(disasm_view)
 
     def on_filter_change(self, **kwargs): #pylint: disable=unused-argument
         pattern = self._filter_string.text()
@@ -88,7 +88,7 @@ class StringsView(BaseView):
                                                 )
 
         self._filter_string = QLineEdit(self)
-        self._regex_checkbox = QCheckBox("Regex?", self)
+        self._regex_checkbox = QCheckBox("Regex", self)
         self._filter_string.textChanged.connect(self.on_filter_change)
         self._regex_checkbox.stateChanged.connect(self.on_filter_change)
 
@@ -98,12 +98,15 @@ class StringsView(BaseView):
         function_layout.addWidget(QLabel("Filter:",self))
         function_layout.addWidget(self._filter_string, 10)
         function_layout.addWidget(self._regex_checkbox)
+        function_layout.setContentsMargins(3, 3, 3, 3)
+        function_layout.setSpacing(4)
 
-        self._string_table = QStringTable(self, selection_callback=self._on_string_selected)
+        self._string_table = QStringTable(self.instance, self, selection_callback=self._on_string_selected)
 
         layout = QVBoxLayout()
         layout.addLayout(function_layout)
         layout.addWidget(self._string_table)
+        layout.setSpacing(0)
         layout.setContentsMargins(0, 0, 0, 0)
 
         self.setLayout(layout)
