@@ -1,5 +1,5 @@
 from typing import Optional, Tuple, TYPE_CHECKING
-from PySide2.QtCore import Qt
+from PySide6.QtCore import Qt
 from enum import Enum
 
 if TYPE_CHECKING:
@@ -19,8 +19,8 @@ class QDisassemblyBaseControl:
     The base control class of QLinearViewer and QDisassemblyGraph. Implements or declares common shorthands and methods.
     """
 
-    def __init__(self, workspace, disasm_view, base_cls):
-        self.workspace = workspace
+    def __init__(self, instance, disasm_view, base_cls):
+        self.instance = instance
         self.disasm_view: 'DisassemblyView' = disasm_view
         self._base_cls = base_cls
         self._insaddr_to_block = { }
