@@ -4,9 +4,10 @@ from typing import List, Set, Tuple, Optional, TYPE_CHECKING
 
 from angr.analyses.code_tagging import CodeTags
 
-from PySide2.QtWidgets import QWidget, QTableView, QAbstractItemView, QHeaderView, QVBoxLayout, QLineEdit
-from PySide2.QtGui import QBrush, QColor, QCursor
-from PySide2.QtCore import Qt, QAbstractTableModel, SIGNAL, QEvent
+from PySide6.QtWidgets import (QWidget, QTableView, QAbstractItemView, QHeaderView, QVBoxLayout, QLineEdit, QLabel,
+                               QHBoxLayout)
+from PySide6.QtGui import QBrush, QColor, QCursor
+from PySide6.QtCore import Qt, QAbstractTableModel, SIGNAL, QEvent
 
 from ..menus.function_context_menu import FunctionContextMenu
 from ...data.instance import ObjectContainer
@@ -14,7 +15,7 @@ from ...config import Conf
 from ..toolbars import FunctionTableToolbar
 
 if TYPE_CHECKING:
-    import PySide2
+    import PySide6
     from ..views.functions_view import FunctionsView
     from angr.knowledge_plugins.functions import Function, FunctionManager
 
@@ -32,12 +33,12 @@ class QFunctionTableModel(QAbstractTableModel):
     SIZE_COL = 4
     BLOCKS_COL = 5
 
-    def __init__(self, workspace, func_list):
+    def __init__(self, instance, func_list):
         super().__init__()
 
         self._func_list = None
         self._raw_func_list = func_list
-        self.workspace = workspace
+        self.instance = instance
         self._config = Conf
 
     def __len__(self):
@@ -64,7 +65,7 @@ class QFunctionTableModel(QAbstractTableModel):
             # remove the filtering
             self._func_list = None
         else:
-            extra_columns = self.workspace.plugins.count_func_columns()
+            extra_columns = self.instance.workspace.plugins.count_func_columns()
             self._func_list = [ func for func in self._raw_func_list if
                                 self._func_match_keyword(func, keyword, extra_columns=extra_columns) ]
 
@@ -76,7 +77,7 @@ class QFunctionTableModel(QAbstractTableModel):
         return len(self.func_list)
 
     def columnCount(self, *args, **kwargs): # pylint:disable=unused-argument
-        return len(self.Headers) + self.workspace.plugins.count_func_columns()
+        return len(self.Headers) + self.instance.workspace.plugins.count_func_columns()
 
     def headerData(self, section, orientation, role): # pylint:disable=unused-argument
         if role != Qt.DisplayRole:
@@ -86,7 +87,7 @@ class QFunctionTableModel(QAbstractTableModel):
             return self.Headers[section]
         else:
             try:
-                return self.workspace.plugins.get_func_column(section - len(self.Headers))
+                return self.instance.workspace.plugins.get_func_column(section - len(self.Headers))
             except IndexError:
                 # Not enough columns
                 return None
@@ -124,7 +125,7 @@ class QFunctionTableModel(QAbstractTableModel):
             return QBrush(color)
 
         elif role == Qt.BackgroundColorRole:
-            color = self.workspace.plugins.color_func(func)
+            color = self.instance.workspace.plugins.color_func(func)
             if color is None:
                 # default colors
                 if func.from_signature:
@@ -160,7 +161,7 @@ class QFunctionTableModel(QAbstractTableModel):
         elif idx == self.BLOCKS_COL:
             return len(func.block_addrs_set)
         else:
-            return self.workspace.plugins.extract_func_column(func, idx - len(self.Headers))[0]
+            return self.instance.workspace.plugins.extract_func_column(func, idx - len(self.Headers))[0]
 
     def _get_column_text(self, func, idx):
         if idx < len(self.Headers):
@@ -172,7 +173,7 @@ class QFunctionTableModel(QAbstractTableModel):
             else:
                 return str(data)
 
-        return self.workspace.plugins.extract_func_column(func, idx - len(self.Headers))[1]
+        return self.instance.workspace.plugins.extract_func_column(func, idx - len(self.Headers))[1]
 
     @staticmethod
     def _get_binary_name(func):
@@ -219,7 +220,7 @@ class QFunctionTableModel(QAbstractTableModel):
             return True
         if extra_columns > 0:
             for idx in range(extra_columns):
-                txt = self.workspace.plugins.extract_func_column(func, idx)[1]
+                txt = self.instance.workspace.plugins.extract_func_column(func, idx)[1]
                 if txt and keyword in txt.lower():
                     return True
         return False
@@ -229,9 +230,9 @@ class QFunctionTableView(QTableView):
     """
     The table view for QFunctionTable.
     """
-    def __init__(self, parent, workspace, selection_callback=None):
+    def __init__(self, parent, instance, selection_callback=None):
         super().__init__(parent)
-        self.workspace = workspace
+        self.instance = instance
         self._context_menu = FunctionContextMenu(self)
 
         self._function_table = parent  # type: QFunctionTable
@@ -241,21 +242,21 @@ class QFunctionTableView(QTableView):
         self.horizontalHeader().setVisible(True)
         self.verticalHeader().setVisible(False)
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
-        self.setHorizontalScrollMode(self.ScrollPerPixel)
-        self.horizontalHeader().setDefaultAlignment(Qt.AlignLeft)
-
-        # sorting
-        # self.horizontalHeader().setSortIndicatorShown(True)
-
-        self.verticalHeader().setSectionResizeMode(QHeaderView.Fixed)
-        self.verticalHeader().setDefaultSectionSize(24)
+        self.setHorizontalScrollMode(QAbstractItemView.ScrollMode.ScrollPerPixel)
 
         self.show_alignment_functions = False
         self._functions = None
-        self._model = QFunctionTableModel(self.workspace, [])
+        self._model = QFunctionTableModel(self.instance, [])
 
         self.setModel(self._model)
 
+        self.horizontalHeader().setDefaultAlignment(Qt.AlignLeft)
+        self.horizontalHeader().setSortIndicatorShown(True)
+        self.horizontalHeader().setSectionResizeMode(0, QHeaderView.Stretch)
+        for i, w in enumerate([80, 80, 80, 50, 50]):
+            self.setColumnWidth(i + 1, w)
+        self.verticalHeader().setDefaultSectionSize(24)
+
         # slots
         self.horizontalHeader().sortIndicatorChanged.connect(self.sortByColumn)
         self.doubleClicked.connect(self._on_function_selected)
@@ -317,9 +318,9 @@ class QFunctionTableView(QTableView):
         self._function_table.show_filter_box(prefix=text)
         return True
 
-    def contextMenuEvent(self, event:'PySide2.QtGui.QContextMenuEvent') -> None: # pylint:disable=unused-argument
+    def contextMenuEvent(self, event:'PySide6.QtGui.QContextMenuEvent') -> None: # pylint:disable=unused-argument
         rows = self.selectionModel().selectedRows()
-        funcs = [self.workspace.instance.kb.functions[r.data()] for r in rows]
+        funcs = [self.instance.kb.functions[r.data()] for r in rows]
         self._context_menu.set(funcs).qmenu().popup(QCursor.pos())
 
 
@@ -353,14 +354,15 @@ class QFunctionTable(QWidget):
     Implements a table for listing function details.
     """
 
-    def __init__(self, parent, workspace, selection_callback=None):
+    def __init__(self, parent, instance, selection_callback=None):
         super().__init__(parent)
-        self.workspace = workspace
+        self.instance = instance
 
         self._view: 'FunctionsView' = parent
         self._table_view = None  # type: QFunctionTableView
         self._filter_box = None  # type: QFunctionTableFilterBox
         self._toolbar = None  # type: FunctionTableToolbar
+        self._status_label = None # type: QLabel
 
         self._last_known_func_addrs: Set[int] = set()
 
@@ -429,11 +431,14 @@ class QFunctionTable(QWidget):
     def update_displayed_function_count(self):
         cnt = self._table_view.model().rowCount()
         if self.function_manager is None:
+            self._status_label.setText("")
             return
         if cnt == len(self.function_manager):
             self._view.set_displayed_function_count(None)  # no filtering
+            self._status_label.setText("%d functions" % cnt)
         else:
             self._view.set_displayed_function_count(cnt)
+            self._status_label.setText("%d/%d functions" % (cnt, len(self.function_manager)))
 
     def filter_functions(self, text):
         self._table_view.filter(text)
@@ -449,7 +454,7 @@ class QFunctionTable(QWidget):
     def _init_widgets(self, selection_callback=None):
 
         # function table view
-        self._table_view = QFunctionTableView(self, self.workspace, selection_callback)
+        self._table_view = QFunctionTableView(self, self.instance, selection_callback)
 
         # filter text box
         self._filter_box = QFunctionTableFilterBox(self)
@@ -460,13 +465,21 @@ class QFunctionTable(QWidget):
         # toolbar
         self._toolbar = FunctionTableToolbar(self)
 
+        self._status_label = QLabel()
+
+        status_lyt = QHBoxLayout()
+        status_lyt.setContentsMargins(3, 3, 3, 3)
+        status_lyt.addWidget(self._toolbar.qtoolbar())
+        status_lyt.addStretch(0)
+        status_lyt.addWidget(self._status_label)
+
         # layout
         layout = QVBoxLayout()
-        layout.addWidget(self._toolbar.qtoolbar())
+        layout.addLayout(status_lyt)
         layout.addWidget(self._filter_box)
         layout.addWidget(self._table_view)
-
         layout.setContentsMargins(0, 0, 0, 0)
+        layout.setSpacing(0)
 
         self.setLayout(layout)
 
