@@ -1,9 +1,9 @@
 import logging
 
-from PySide2.QtWidgets import QGraphicsScene, QGraphicsView, QStyleOptionGraphicsItem, QApplication,\
+from PySide6.QtWidgets import QGraphicsScene, QGraphicsView, QStyleOptionGraphicsItem, QApplication,\
     QGraphicsSceneMouseEvent
-from PySide2.QtGui import QPainter, QMouseEvent, QImage, QVector2D
-from PySide2.QtCore import Qt, QSize, QEvent, QMarginsF, Signal, QRectF
+from PySide6.QtGui import QPainter, QMouseEvent, QImage, QVector2D
+from PySide6.QtCore import Qt, QSize, QEvent, QMarginsF, Signal, QRectF, QPoint
 
 _l = logging.getLogger(__name__)
 
@@ -72,7 +72,7 @@ class QSaveableGraphicsView(QBaseGraphicsView):
         painter = QPainter(image)
 
         painter.setRenderHints(
-                QPainter.Antialiasing | QPainter.SmoothPixmapTransform | QPainter.HighQualityAntialiasing)
+                QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
 
         # draw the image
         self.scene().setSceneRect(imgRect)
@@ -110,13 +110,13 @@ class QZoomableDraggableGraphicsView(QSaveableGraphicsView):
         self.zoom_factor = None
 
         #self.setRenderHints(
-                #QPainter.Antialiasing | QPainter.SmoothPixmapTransform | QPainter.HighQualityAntialiasing)
+                #QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
 
     def _initial_position(self):
         raise NotImplementedError
 
     def _reset_view(self):
-        self.resetMatrix()
+        self.resetTransform()
         self.centerOn(self._initial_position())
         self.zoom(restore=True)
 
@@ -130,11 +130,11 @@ class QZoomableDraggableGraphicsView(QSaveableGraphicsView):
     def sizeHint(self):  # pylint:disable=no-self-use
         return QSize(300, 300)
 
-    def zoom(self, out=False, at=None, reset=False, restore=False):
+    def zoom(self, out=False, at=None, reset=False, restore=False, factor=1.25):
         if at is None:
             at = self.scene().sceneRect().center().toPoint()
         lod = QStyleOptionGraphicsItem.levelOfDetailFromTransform(self.transform())
-        zoomInFactor = 1.25
+        zoomInFactor = factor
         zoomOutFactor = 1 / zoomInFactor
 
         if reset:
@@ -165,8 +165,12 @@ class QZoomableDraggableGraphicsView(QSaveableGraphicsView):
 
     def wheelEvent(self, event):
         if event.modifiers() & Qt.ControlModifier == Qt.ControlModifier:
-            self.zoom(event.delta() < 0, event.pos())
-        elif event.angleDelta().y() != event.delta() or event.angleDelta().x() != 0:
+            self.zoom(
+                event.angleDelta().y() < 0,
+                QPoint(event.position().x(), event.position().y()),
+                factor=1 + 0.25 * abs(event.angleDelta().y()) / 120,
+            )
+        elif event.angleDelta().x() != 0:
             # if this is an angled zoom (e.g. touchpad) then just let the default handler take care of it
             super().wheelEvent(event)
         else:
