@@ -1,7 +1,7 @@
 from typing import List, TYPE_CHECKING, Dict
-from PySide2.QtGui import QColor, QPainterPath, QBrush, QCursor
-from PySide2.QtCore import QMarginsF
-from PySide2.QtWidgets import QGraphicsItem, QGraphicsSimpleTextItem, QGraphicsSceneMouseEvent, QMenu, \
+from PySide6.QtGui import QColor, QPainterPath, QBrush, QCursor
+from PySide6.QtCore import QMarginsF
+from PySide6.QtWidgets import QGraphicsItem, QGraphicsSimpleTextItem, QGraphicsSceneMouseEvent, QMenu, \
     QInputDialog, QLineEdit
 
 from .qsimulation_managers import QSimulationManagers
@@ -28,7 +28,7 @@ class QInstructionAnnotation(QGraphicsSimpleTextItem):
 
     @property
     def symexec_view(self) -> 'SymexecView':
-        return self.parentItem().disasm_view.workspace.view_manager.first_view_in_category("symexec")
+        return self.parentItem().disasm_view.instance.workspace.view_manager.first_view_in_category("symexec")
 
     def __init__(self, addr, text, *args, **kwargs):
         super().__init__(text, *args, **kwargs)
@@ -102,7 +102,7 @@ class QActiveCount(QStatsAnnotation):
             symexec_view = self.symexec_view
             if symexec_view:
                 symexec_view.select_states(self.states)
-                symexec_view.workspace.raise_view(symexec_view)
+                symexec_view.instance.workspace.raise_view(symexec_view)
 
         def _move_states():
             disasm_view = self.disasm_view
@@ -154,7 +154,7 @@ class QHookAnnotation(QInstructionAnnotation):
         menu.exec_(QCursor.pos())
 
     def delete(self):
-        self.disasm_view.workspace.instance.delete_hook(self.addr)
+        self.disasm_view.instance.delete_hook(self.addr)
         self.disasm_view.refresh()
 
 
@@ -213,7 +213,7 @@ class QBreakAnnotation(QInstructionAnnotation):
         menu.exec_(QCursor.pos())
 
     def delete(self):
-        self.disasm_view.workspace.instance.breakpoint_mgr.remove_breakpoint(self.bp)
+        self.disasm_view.instance.breakpoint_mgr.remove_breakpoint(self.bp)
 
 
 class QAvoidAddrAnnotation(QExploreAnnotation):
