@@ -2,9 +2,9 @@ from typing import Optional, TYPE_CHECKING, Union
 import logging
 from sortedcontainers import SortedDict
 
-from PySide2.QtWidgets import QGraphicsScene, QAbstractSlider, QHBoxLayout, QAbstractScrollArea
-from PySide2.QtGui import QPainter
-from PySide2.QtCore import Qt, QRectF, QRect, QEvent
+from PySide6.QtWidgets import QGraphicsScene, QAbstractSlider, QHBoxLayout, QAbstractScrollArea
+from PySide6.QtGui import QPainter
+from PySide6.QtCore import Qt, QRectF, QRect, QEvent
 
 from angr.block import Block
 from angr.knowledge_plugins.cfg.memory_data import MemoryData
@@ -36,8 +36,7 @@ class QLinearDisassemblyView(QSaveableGraphicsView):
         self._scene = QGraphicsScene(0, 0, self.width(), self.height())
         self.setAlignment(Qt.AlignTop | Qt.AlignLeft)
         self.setScene(self._scene)
-        self.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform |
-                            QPainter.HighQualityAntialiasing)
+        self.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
 
         # Do not use the scrollbars since they are hard-linked to the size of the scene, which is bad for us
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
@@ -62,8 +61,8 @@ class QLinearDisassemblyView(QSaveableGraphicsView):
 class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
     OBJECT_PADDING = 0
 
-    def __init__(self, workspace, disasm_view, parent=None):
-        QDisassemblyBaseControl.__init__(self, workspace, disasm_view, QAbstractScrollArea)
+    def __init__(self, instance, disasm_view, parent=None):
+        QDisassemblyBaseControl.__init__(self, instance, disasm_view, QAbstractScrollArea)
         QAbstractScrollArea.__init__(self, parent=parent)
 
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
@@ -123,11 +122,11 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
 
     @property
     def cfg(self):
-        return self.workspace.instance.cfg
+        return self.instance.cfg
 
     @property
     def cfb(self):
-        return self.workspace.instance.cfb
+        return self.instance.cfb
 
     @property
     def scene(self):
@@ -156,7 +155,7 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
         :param QWheelEvent event:
         :return:
         """
-        delta = event.delta()
+        delta = event.angleDelta().y()
         if delta < 0:
             # scroll down by some lines
             lines = min(int(-delta // self._line_height), 3)
@@ -179,6 +178,8 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
 
     def _on_vertical_scroll_bar_triggered(self, action):
 
+        action = QAbstractSlider.SliderAction(action)  # XXX: `action` is passed as an int
+
         if action == QAbstractSlider.SliderSingleStepAdd:
             # scroll down by one line
             self.prepare_objects(self.offset, start_line=self._start_line_in_object + 1)
@@ -259,7 +260,6 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
         :param use_block_pos:
         :return:
         """
-
         if insn_pos is not None:
             # check if item is already visible in the viewport
             viewport = self._viewer.viewport()
@@ -338,7 +338,6 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
         _l.debug("Address %#x, offset %d, start_line %d.", addr, offset, start_line)
 
         self._insaddr_to_block.clear()
-
         if start_line < 0:
             # Which object are we currently displaying at the top of the disassembly view?
             try:
@@ -439,8 +438,8 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
             cfg_node = self.cfg.get_any_node(obj_addr, force_fastpath=True)
             if cfg_node is not None:
                 func_addr = cfg_node.function_address
-                if self.workspace.instance.kb.functions.contains_addr(func_addr):
-                    func = self.workspace.instance.kb.functions[func_addr]
+                if self.instance.kb.functions.contains_addr(func_addr):
+                    func = self.instance.kb.functions[func_addr]
                     disasm = self._get_disasm(func)
                     qobject = None
                     if self._disassembly_level is DisassemblyLevel.AIL:
@@ -452,11 +451,11 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
                                     ail_obj = n
                             # the corresponding AIL block may not exist
                             if ail_obj is not None:
-                                qobject = QLinearBlock(self.workspace, func_addr, self.disasm_view, disasm,
+                                qobject = QLinearBlock(self.instance, func_addr, self.disasm_view, disasm,
                                                        self.disasm_view.infodock, obj.addr, ail_obj, None, None
                                                        )
                     else:
-                        qobject = QLinearBlock(self.workspace, func_addr, self.disasm_view, disasm,
+                        qobject = QLinearBlock(self.instance, func_addr, self.disasm_view, disasm,
                                                self.disasm_view.infodock, obj.addr, [obj], {}, None
                                                )
                 else:
@@ -468,9 +467,9 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
                 _l.warning("Failed to get a CFG node for address %#x.", obj_addr)
                 qobject = None
         elif isinstance(obj, MemoryData):
-            qobject = QMemoryDataBlock(self.workspace, self.disasm_view.infodock, obj_addr, obj, parent=None)
+            qobject = QMemoryDataBlock(self.instance, self.disasm_view.infodock, obj_addr, obj, parent=None)
         elif isinstance(obj, Unknown):
-            qobject = QUnknownBlock(self.workspace, obj_addr, obj.bytes)
+            qobject = QUnknownBlock(self.instance, obj_addr, obj.bytes)
         else:
             qobject = None
         return qobject
@@ -499,10 +498,10 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
         """
         if self._disassembly_level is DisassemblyLevel.AIL:
             if func.addr not in self._ail_disasms:
-                self._ail_disasms[func.addr] = self.workspace.instance.project.analyses.Clinic(func)
+                self._ail_disasms[func.addr] = self.instance.project.analyses.Clinic(func)
             return self._ail_disasms[func.addr]
 
         if func.addr not in self._disasms:
             include_ir = self._disassembly_level is DisassemblyLevel.LifterIR
-            self._disasms[func.addr] = self.workspace.instance.project.analyses.Disassembly(function=func, include_ir=include_ir)
+            self._disasms[func.addr] = self.instance.project.analyses.Disassembly(function=func, include_ir=include_ir)
         return self._disasms[func.addr]
