@@ -3,15 +3,15 @@ import os
 import logging
 from typing import List, Any, Optional
 
-import PySide2
-from PySide2.QtWidgets import QTableView, QAbstractItemView, QHeaderView
-from PySide2.QtCore import QAbstractTableModel, Qt
-from PySide2.QtGui import QIcon, QCursor, QGuiApplication, QClipboard, QKeySequence
+import PySide6
+from PySide6.QtWidgets import QTableView, QAbstractItemView, QHeaderView
+from PySide6.QtCore import QAbstractTableModel, Qt
+from PySide6.QtGui import QIcon, QCursor, QGuiApplication, QClipboard, QKeySequence
 
-from ...config import IMG_LOCATION
-from ...logic.threads import gui_thread_schedule_async
-from ...data.log import LogRecord
-from ..menus.log_menu import LogMenu
+from angrmanagement.config import IMG_LOCATION
+from angrmanagement.logic.threads import gui_thread_schedule_async
+from angrmanagement.data.log import LogRecord
+from angrmanagement.ui.menus.log_menu import LogMenu
 
 
 class QLogIcons:
@@ -62,20 +62,20 @@ class QLogTableModel(QAbstractTableModel):
     def log(self) -> List[LogRecord]:
         return self._log
 
-    def rowCount(self, parent:PySide2.QtCore.QModelIndex=...) -> int:
+    def rowCount(self, parent:PySide6.QtCore.QModelIndex=...) -> int:
         return len(self._log)
 
-    def columnCount(self, parent:PySide2.QtCore.QModelIndex=...) -> int:
+    def columnCount(self, parent:PySide6.QtCore.QModelIndex=...) -> int:
         return len(self.Headers)
 
-    def headerData(self, section:int, orientation:PySide2.QtCore.Qt.Orientation, role:int=...) -> Any:
+    def headerData(self, section:int, orientation:PySide6.QtCore.Qt.Orientation, role:int=...) -> Any:
         if role != Qt.DisplayRole:
             return None
         if section < len(self.Headers):
             return self.Headers[section]
         return None
 
-    def data(self, index:PySide2.QtCore.QModelIndex, role:int=...) -> Any:
+    def data(self, index:PySide6.QtCore.QModelIndex, role:int=...) -> Any:
         if not index.isValid():
             return None
         row = index.row()
@@ -145,7 +145,7 @@ class QLogWidget(QTableView):
         hheader.setStretchLastSection(True)
         vheader.setVisible(False)
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
-        self.setHorizontalScrollMode(self.ScrollPerPixel)
+        self.setHorizontalScrollMode(QAbstractItemView.ScrollPerPixel)
         vheader.setDefaultSectionSize(20)
         self.setShowGrid(False)
 
@@ -156,15 +156,15 @@ class QLogWidget(QTableView):
         self.setColumnWidth(0, 20)
         hheader.setSectionResizeMode(1, QHeaderView.ResizeToContents)
 
-        self.log_view.workspace.instance.log.am_subscribe(self._on_new_logrecord)
+        self.log_view.instance.log.am_subscribe(self._on_new_logrecord)
 
     #
     # Public methods
     #
 
     def clear_log(self):
-        self.log_view.workspace.instance.log.am_obj = [ ]
-        self.log_view.workspace.instance.log.am_event()
+        self.log_view.instance.log.am_obj = [ ]
+        self.log_view.instance.log.am_event()
 
     def copy_selected(self):
         content = [ ]
@@ -206,10 +206,10 @@ class QLogWidget(QTableView):
     #
 
     def closeEvent(self, event):
-        self.log_view.workspace.instance.log.am_unsubscribe(self._on_new_logrecord)
+        self.log_view.instance.log.am_unsubscribe(self._on_new_logrecord)
         super().closeEvent(event)
 
-    def contextMenuEvent(self, arg__1: PySide2.QtGui.QContextMenuEvent):
+    def contextMenuEvent(self, arg__1: PySide6.QtGui.QContextMenuEvent):
         self._context_menu.popup(QCursor.pos())
 
     def _on_new_logrecord(self, log_record: LogRecord = None):
@@ -221,7 +221,7 @@ class QLogWidget(QTableView):
         if log_record is None:
             # reload
             self.model.layoutAboutToBeChanged.emit()
-            self.model._log = self.log_view.workspace.instance.log[::]
+            self.model._log = self.log_view.instance.log[::]
             self.model.layoutChanged.emit()
         else:
             log_records = len(self.model.log)
@@ -239,7 +239,7 @@ class QLogWidget(QTableView):
         if self._auto_scroll:
             self.scrollToBottom()
 
-    def keyPressEvent(self, event:PySide2.QtGui.QKeyEvent):
+    def keyPressEvent(self, event:PySide6.QtGui.QKeyEvent):
         if event.matches(QKeySequence.Copy):
             self.copy_selected_messages()
         else:
