@@ -1,17 +1,14 @@
 
-from PySide2.QtGui import QColor
-from PySide2.QtCore import Qt, QRectF
+from PySide6.QtCore import Qt, QRectF
 
-from ...utils.block_objects import PhiVariable
 from .qgraph_object import QCachedGraphicsItem
-from .qvariable import QVariable
 
 
 class QPhiVariable(QCachedGraphicsItem):
 
     IDENT_LEFT_PADDING = 5
 
-    def __init__(self, workspace, disasm_view, phi_variable, config, parent=None):
+    def __init__(self, instance, disasm_view, phi_variable, config, parent=None):
         """
 
         :param workspace:
@@ -23,7 +20,7 @@ class QPhiVariable(QCachedGraphicsItem):
         super().__init__(parent=parent)
 
         # initialization
-        self.workspace = workspace
+        self.instance = instance
         self.disasm_view = disasm_view
         self.phi = phi_variable.variable  # the major variable
         self.variables = phi_variable.variables  # the sub variables
